@@ -1,21 +1,24 @@
 package commands
 
 import (
-	"errors"
-	"github.com/codegangsta/cli"
-	"github.com/jfrog/jfrog-cli-core/utils/coreutils"
-	"github.com/jfrog/jfrog-cli/plugins/commands/utils"
+	"github.com/jfrog/jfrog-cli-core/v2/utils/coreutils"
+	"github.com/jfrog/jfrog-cli-core/v2/utils/plugins"
 	"github.com/jfrog/jfrog-cli/utils/cliutils"
 	clientutils "github.com/jfrog/jfrog-client-go/utils"
 	"github.com/jfrog/jfrog-client-go/utils/errorutils"
 	"github.com/jfrog/jfrog-client-go/utils/io/fileutils"
+	"github.com/urfave/cli"
 	"os"
 	"path/filepath"
 )
 
 func UninstallCmd(c *cli.Context) error {
 	if c.NArg() != 1 {
-		return cliutils.PrintHelpAndReturnError("Wrong number of arguments.", c)
+		return cliutils.WrongNumberOfArgumentsHandler(c)
+	}
+	err := plugins.CheckPluginsVersionAndConvertIfNeeded()
+	if err != nil {
+		return err
 	}
 	return runUninstallCmd(c.Args().Get(0))
 }
@@ -25,8 +28,8 @@ func runUninstallCmd(requestedPlugin string) error {
 	if err != nil {
 		return err
 	}
-	pluginExePath := filepath.Join(pluginsDir, utils.GetLocalPluginExecutableName(requestedPlugin))
-	exists, err := fileutils.IsFileExists(pluginExePath, false)
+	requestedPluginDirPath := filepath.Join(pluginsDir, requestedPlugin)
+	exists, err := fileutils.IsDirExists(requestedPluginDirPath, false)
 	if err != nil {
 		return err
 	}
@@ -43,9 +46,9 @@ func runUninstallCmd(requestedPlugin string) error {
 			return nil
 		}
 	}
-	return os.Remove(pluginExePath)
+	return errorutils.CheckError(os.RemoveAll(requestedPluginDirPath))
 }
 
 func generateNoPluginFoundError(pluginName string) error {
-	return errorutils.CheckError(errors.New("plugin '" + pluginName + "' could not be found"))
+	return errorutils.CheckErrorf("plugin '" + pluginName + "' could not be found")
 }
