@@ -7,6 +7,7 @@ import (
 	"errors"
 	"flag"
 	"fmt"
+	ioutils "github.com/jfrog/gofrog/io"
 	"github.com/jfrog/jfrog-client-go/utils/tests"
 	"io"
 	"math/rand"
@@ -223,12 +224,7 @@ func DeleteFiles(deleteSpec *spec.SpecFiles, serverDetails *config.ServerDetails
 	if err != nil {
 		return 0, 0, err
 	}
-	defer func() {
-		e := reader.Close()
-		if err == nil {
-			err = e
-		}
-	}()
+	defer ioutils.Close(reader, &err)
 	return deleteCommand.DeleteFiles(reader)
 }
 
@@ -245,37 +241,39 @@ func GetBuildInfo(serverDetails *config.ServerDetails, buildName, buildNumber st
 }
 
 var reposConfigMap = map[*string]string{
-	&DistRepo1:              DistributionRepoConfig1,
-	&DistRepo2:              DistributionRepoConfig2,
-	&GoRepo:                 GoLocalRepositoryConfig,
-	&GoRemoteRepo:           GoRemoteRepositoryConfig,
-	&GoVirtualRepo:          GoVirtualRepositoryConfig,
-	&GradleRepo:             GradleRepositoryConfig,
-	&MvnRepo1:               MavenRepositoryConfig1,
-	&MvnRepo2:               MavenRepositoryConfig2,
-	&MvnRemoteRepo:          MavenRemoteRepositoryConfig,
-	&GradleRemoteRepo:       GradleRemoteRepositoryConfig,
-	&NpmRepo:                NpmLocalRepositoryConfig,
-	&NpmRemoteRepo:          NpmRemoteRepositoryConfig,
-	&NugetRemoteRepo:        NugetRemoteRepositoryConfig,
-	&YarnRemoteRepo:         YarnRemoteRepositoryConfig,
-	&PypiRemoteRepo:         PypiRemoteRepositoryConfig,
-	&PypiVirtualRepo:        PypiVirtualRepositoryConfig,
-	&PipenvRemoteRepo:       PipenvRemoteRepositoryConfig,
-	&PipenvVirtualRepo:      PipenvVirtualRepositoryConfig,
-	&RtDebianRepo:           DebianTestRepositoryConfig,
-	&RtLfsRepo:              GitLfsTestRepositoryConfig,
-	&RtRepo1:                Repo1RepositoryConfig,
-	&RtRepo2:                Repo2RepositoryConfig,
-	&RtVirtualRepo:          VirtualRepositoryConfig,
-	&TerraformRepo:          TerraformLocalRepositoryConfig,
-	&DockerLocalRepo:        DockerLocalRepositoryConfig,
-	&DockerLocalPromoteRepo: DockerLocalPromoteRepositoryConfig,
-	&DockerRemoteRepo:       DockerRemoteRepositoryConfig,
-	&DockerVirtualRepo:      DockerVirtualRepositoryConfig,
-	&RtDevRepo:              DevRepoRepositoryConfig,
-	&RtProdRepo1:            ProdRepo1RepositoryConfig,
-	&RtProdRepo2:            ProdRepo2RepositoryConfig,
+	&DistRepo1:                      DistributionRepoConfig1,
+	&DistRepo2:                      DistributionRepoConfig2,
+	&GoRepo:                         GoLocalRepositoryConfig,
+	&GoRemoteRepo:                   GoRemoteRepositoryConfig,
+	&GoVirtualRepo:                  GoVirtualRepositoryConfig,
+	&GradleRepo:                     GradleRepositoryConfig,
+	&MvnRepo1:                       MavenRepositoryConfig1,
+	&MvnRepo2:                       MavenRepositoryConfig2,
+	&MvnRemoteRepo:                  MavenRemoteRepositoryConfig,
+	&GradleRemoteRepo:               GradleRemoteRepositoryConfig,
+	&NpmRepo:                        NpmLocalRepositoryConfig,
+	&NpmRemoteRepo:                  NpmRemoteRepositoryConfig,
+	&NugetRemoteRepo:                NugetRemoteRepositoryConfig,
+	&YarnRemoteRepo:                 YarnRemoteRepositoryConfig,
+	&PypiLocalRepo:                  PypiLocalRepositoryConfig,
+	&PypiRemoteRepo:                 PypiRemoteRepositoryConfig,
+	&PypiVirtualRepo:                PypiVirtualRepositoryConfig,
+	&PipenvRemoteRepo:               PipenvRemoteRepositoryConfig,
+	&PipenvVirtualRepo:              PipenvVirtualRepositoryConfig,
+	&RtDebianRepo:                   DebianTestRepositoryConfig,
+	&RtLfsRepo:                      GitLfsTestRepositoryConfig,
+	&RtRepo1:                        Repo1RepositoryConfig,
+	&RtRepo2:                        Repo2RepositoryConfig,
+	&RtVirtualRepo:                  VirtualRepositoryConfig,
+	&TerraformRepo:                  TerraformLocalRepositoryConfig,
+	&DockerLocalRepo:                DockerLocalRepositoryConfig,
+	&DockerLocalPromoteRepo:         DockerLocalPromoteRepositoryConfig,
+	&DockerRemoteRepo:               DockerRemoteRepositoryConfig,
+	&DockerVirtualRepo:              DockerVirtualRepositoryConfig,
+	&RtDevRepo:                      DevRepoRepositoryConfig,
+	&RtProdRepo1:                    ProdRepo1RepositoryConfig,
+	&RtProdRepo2:                    ProdRepo2RepositoryConfig,
+	&ReleaseLifecycleDependencyRepo: ReleaseLifecycleImportDependencySpec,
 }
 
 var CreatedNonVirtualRepositories map[*string]string
@@ -308,7 +306,7 @@ func getNeededBuildNames(buildNamesMap map[*bool][]*string) []string {
 // Return local and remote repositories for the test suites, respectfully
 func GetNonVirtualRepositories() map[*string]string {
 	nonVirtualReposMap := map[*bool][]*string{
-		TestArtifactory:        {&RtRepo1, &RtRepo2, &RtLfsRepo, &RtDebianRepo, &TerraformRepo},
+		TestArtifactory:        {&RtRepo1, &RtRepo2, &RtLfsRepo, &RtDebianRepo, &TerraformRepo, &ReleaseLifecycleDependencyRepo},
 		TestArtifactoryProject: {&RtRepo1, &RtRepo2, &RtLfsRepo, &RtDebianRepo},
 		TestDistribution:       {&DistRepo1, &DistRepo2},
 		TestDocker:             {&DockerLocalRepo, &DockerLocalPromoteRepo, &DockerRemoteRepo},
@@ -319,7 +317,7 @@ func GetNonVirtualRepositories() map[*string]string {
 		TestMaven:              {&MvnRepo1, &MvnRepo2, &MvnRemoteRepo},
 		TestNpm:                {&NpmRepo, &NpmRemoteRepo},
 		TestNuget:              {&NugetRemoteRepo},
-		TestPip:                {&PypiRemoteRepo},
+		TestPip:                {&PypiLocalRepo, &PypiRemoteRepo},
 		TestPipenv:             {&PipenvRemoteRepo},
 		TestPlugins:            {&RtRepo1},
 		TestXray:               {&NpmRemoteRepo, &NugetRemoteRepo, &YarnRemoteRepo, &GradleRemoteRepo, &MvnRemoteRepo, &GoRepo, &GoRemoteRepo, &PypiRemoteRepo},
@@ -424,6 +422,7 @@ func getSubstitutionMap() map[string]string {
 		"${PASSWORD}":                  *JfrogPassword,
 		"${RT_CREDENTIALS_BASIC_AUTH}": base64.StdEncoding.EncodeToString([]byte(*JfrogUser + ":" + *JfrogPassword)),
 		"${ACCESS_TOKEN}":              *JfrogAccessToken,
+		"${PYPI_LOCAL_REPO}":           PypiLocalRepo,
 		"${PYPI_REMOTE_REPO}":          PypiRemoteRepo,
 		"${PYPI_VIRTUAL_REPO}":         PypiVirtualRepo,
 		"${PIPENV_REMOTE_REPO}":        PipenvRemoteRepo,
@@ -482,6 +481,7 @@ func AddTimestampToGlobalVars() {
 	NpmRemoteRepo += uniqueSuffix
 	NugetRemoteRepo += uniqueSuffix
 	YarnRemoteRepo += uniqueSuffix
+	PypiLocalRepo += uniqueSuffix
 	PypiRemoteRepo += uniqueSuffix
 	PypiVirtualRepo += uniqueSuffix
 	PipenvRemoteRepo += uniqueSuffix
